<template>
  <section
    :class="{ ['color' + tv.shop_color]: true, ['layout' + tv.shop_style]: true }"
    class="tv">
    <div class="shop-html">
      <div class="shop-body">
        <div
          v-show="tv.shop_style == 1"
          id="background">
          <div id="desk-camera">
            <div class="headerwidthcontainer">
              <div id="yatlogo">
                <img
                  id="yatlogoimg"
                  :src="logo"
                  width="98"
                  height="81">
              </div>
              <div id="shopname">{{ tv.name }}</div>
              <div id="shopdesc">
                <div class="inner">{{ tv.description }}</div>
              </div>
            </div>
            <div class="contentwidthcontainer">
              <div id="sidebar">
                <div
                  v-if="tv.admin"
                  id="menu">
                  <ul
                    id="nav"
                    class="tab-buttons">
                    <router-link
                      :to="{name: 'tvmain'}"
                      tag="li">
                      <a
                        :class="{selected: (this.$route.name === 'tvmain')}"
                        class="tab">Main Page
                      </a>
                    </router-link>
                    <router-link
                      :to="{name: 'tvaccounting'}"
                      tag="li">
                      <a
                        :class="{selected: (this.$route.name === 'tvaccounting')}"
                        class="tab">Accounting
                      </a>
                    </router-link>
                    <div class="clear"/>
                  </ul>
                </div>
                <div class="date">{{ moment(Date.now()).format("MMMM Do, YYYY") }}</div>
                <div class="kiosks">
                  <div class="kioskstitle">
                    <span>KIOSKS</span><br >CONNECTING YOU <br >TO TOWNE
                  </div>
                </div>
                <div class="kiosklist">
                  <p>With our kiosks you can:
                    <ul>
                      <li>"Like" your favorite shops</li>
                      <li>Check your balance</li>
                      <li>Sign up for rewards</li>
                    </ul>
                    .....and much more!</p>
                </div>
                <headlines />
                <action-buttons
                  v-if="Object.keys(tv).length"
                  :has-swiper="hasSwiper"
                  :shop="tv" />
              </div>
              <div id="mainpagecontent">
                <router-view
                  :shop="tv"
                  :tv-content="tvContent"
                  @simple-one="simpleOne"
                  @simple-two="simpleTwo"
                  @busy-one="busyOne"
                  @busy-two="busyTwo"/>
              </div>
              <div class="clear"/>
            </div>
          </div>
        </div>
        <div
          v-show="tv.shop_style == 2"
          class="outer">
          <div id="yatlogo">
            <img
              id="yatlogoimg"
              :src="logo"
              width="98"
              height="81">
          </div>
          <div class="headerwidthcontainer">
            <section class="banner">
              <div class="shopnamebg">{{ tv.name }}</div>
              <div id="shopname">{{ tv.name }}</div>
            </section>
            <div
              v-if="tv.admin"
              id="menu">
              <ul
                id="nav"
                class="tab-buttons">
                <router-link
                  :to="{name: 'tvmain'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'tvmain')}"
                    class="tab">Main Page
                  </a>
                </router-link>
                <router-link
                  :to="{name: 'tvaccounting'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'tviaccounting')}"
                    class="tab">Accounting
                  </a>
                </router-link>
                <div class="clear"/>
              </ul>
              <div class="date">{{ moment(Date.now()).format("dddd, MMMM Do, YYYY") }}</div>
            </div>
          </div>
          <div class="contentwidthcontainer">
            <div id="sidebar">
              <div class="kiosks">
                <div class="kioskstitle">
                  <span>KIOSKS</span><br >CONNECTING YOU TO TOWNE
                </div>
              </div>
              <div class="kiosklist">
                <p>With our kiosks you can:
                  <ul>
                    <li>"Like" your favorite shops</li>
                    <li>Check your balance</li>
                    <li>Sign up for rewards</li>
                  </ul>
                  .....and much more!</p>
              </div>
              <headlines />
              <action-buttons
                v-if="Object.keys(tv).length"
                :has-swiper="hasSwiper"
                :shop="tv" />
            </div>
            <div id="mainpagecontent">
              <router-view
                :shop="tv"
                :tv-content="tvContent"
                @simple-one="simpleOne"
                @simple-two="simpleTwo"
                @busy-one="busyOne"
                @busy-two="busyTwo"/>
            </div>
            <div class="clear"/>
          </div>
        </div>
      </div>
    </div>
  </section>
</template>

<script>
import ShopBaseView from "../shopBase.js";
import Headlines from "../Headlines.vue";
import ActionButtons from "../ActionButtons.vue";

export default {
  components: {
    Headlines,
    ActionButtons,
  },
  extends: ShopBaseView,
  data() {
    return {
      tvContent: app.network.data.tv_station_content_localization,
      logo: app.network.data.shop_logo,
      tv: {},
      hasSwiper: app.computerSettings.swiper,
    };
  },
  created: function () {
    this.getData();
  },
  beforeMount: function () {
    this.$router.push({name: "tvmain"});
  },
  methods: {
    getData() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "/tv/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.tv = Response;
            app.Message( "Successfully loaded the TV Station!", "success" );
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
    },
    simpleOne() {
      this.tv.shop_style = 1;
      this.tv.shop_color = 1;
    },
    simpleTwo() {
      this.tv.shop_style = 1;
      this.tv.shop_color = 2;
    },
    busyOne() {
      this.tv.shop_style = 2;
      this.tv.shop_color = 1;
    },
    busyTwo() {
      this.tv.shop_style = 2;
      this.tv.shop_color = 2;
    },
  },

};
</script>

<style lang="less">
  @import '../../shared.less';
</style>


<style lang="less">
.tv.layout1.color1 {
  /* TV common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @logoborder: 0.5rem solid #820000;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @tabactivefontcolor: #fff;
  @activemenutabcolor: rgba(255,255,255,.3);
  @maincontentcolor: #ffffff;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }

  .bggradient() {
    background: -moz-linear-gradient(top,  rgba(0,0,0,0.83) 0%, rgba(0,0,0,0.83) 60%, rgba(0,0,0,0.53) 84%, rgba(0,0,0,0) 100%);
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(0,0,0,0.83)), color-stop(60%,rgba(0,0,0,0.83)), color-stop(84%,rgba(0,0,0,0.53)), color-stop(100%,rgba(0,0,0,0)));
    background: -webkit-linear-gradient(top,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    background: -o-linear-gradient(top,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    background: -ms-linear-gradient(top,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    background: linear-gradient(to bottom,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#d4000000', endColorstr='#00000000',GradientType=0 );
  }
  // TV color 1
  @bgcolor:#373735;
  @bgimage: url(/images/shop/tv/tvbg.jpg);
  @bgimage2:url(/images/shop/tv/tvbackdropbg.png);
  @headerbg:url(/images/shop/tv/tvdesk.png);
  @shoptitlecolor: #fff;
  @shopnameshadow:.4rem .4rem 0rem #820000;
  @contentbgimage:url(/images/shop/utility/pipebg.png);
  @shopdesccolor:#fff;
  @homemsgcolor:#144a68;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @tabfontcolor: #fff;
  @kioskbg:#820000;
  @maincontentp:#2a5d8c;
  @maincontenth1:#fff;
  @h1shadow:none;
  @activetabcolor:#fff;
  @buttonbackground:#2a5d8c;
  @buttonborder:#236db2;
  @buttonhoverbg:#1a4872;
  @buttonborderhover:#236db2;
  @tvh3bg:#2a5d8c;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;

  @import './tvLayout1.less';
}

</style>

<style lang="less">
.tv.layout1.color2 {
   /* TV common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @logoborder: 0.5rem solid #820000;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @tabactivefontcolor: #fff;
  @activemenutabcolor: rgba(255,255,255,.3);
  @maincontentcolor: #ffffff;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }

  .bggradient() {
    background: -moz-linear-gradient(top,  rgba(0,0,0,0.83) 0%, rgba(0,0,0,0.83) 60%, rgba(0,0,0,0.53) 84%, rgba(0,0,0,0) 100%);
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(0,0,0,0.83)), color-stop(60%,rgba(0,0,0,0.83)), color-stop(84%,rgba(0,0,0,0.53)), color-stop(100%,rgba(0,0,0,0)));
    background: -webkit-linear-gradient(top,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    background: -o-linear-gradient(top,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    background: -ms-linear-gradient(top,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    background: linear-gradient(to bottom,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#d4000000', endColorstr='#00000000',GradientType=0 );
  }
  // TV color 2
  @bgcolor:#a1a09b;
  @bgimage: url(/images/shop/tv/tv2bg.jpg);
  @bgimage2:url(/images/shop/tv/tvbackdrop2bg.png);
  @headerbg:url(/images/shop/tv/tvdesk2.png);
  @shoptitlecolor: #820000;
  @shopnameshadow:0rem 0rem 4rem #fff;
  @contentbgimage:url(/images/shop/utility/pipe2bg.png);
  @shopdesccolor:#fff;
  @homemsgcolor:#7f0000;
  @navbgcolor: #2e55b0;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @tabfontcolor: #fff;
  @kioskbg:#2a5d8c;
  @maincontentp:#820000;
  @maincontenth1:#fff;
  @h1shadow:none;
  @activetabcolor:#fff;
  @buttonbackground:#820000;
  @buttonborder:#6f0000;
  @buttonhoverbg:#5a0101;
  @buttonborderhover:#6f0000;
  @tvh3bg:#820000;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;

  @import './tvLayout1.less';
}

</style>

<style lang="less">
.tv.layout2.color1 {
  .clearfix:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }
  .clearfix { display: inline-block; }
  * .shop-html .clearfix { height: 1%; }
  .clearfix { display: block; }

  /* TV common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @logoborder: 0.5rem solid #820000;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @tabactivefontcolor: #fff;
  @font-face {
      font-family: 'fugaz_oneregular';
      src: url('/fonts/FugazOne/fugazone-regular.eot');
      src: url('/fonts/FugazOne/fugazone-regular.eot?#iefix') format('embedded-opentype'),
          url('/fonts/FugazOne/fugazone-regular.woff') format('woff'),
          url('/fonts/FugazOne/fugazone-regular.ttf') format('truetype'),
          url('/fonts/FugazOne/fugazone-regular.svg#fugaz_oneregular') format('svg');
      font-weight: normal;
      font-style: normal;

  }
  @maincontentcolor: #2e2e2e;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }

  .bggradient() {
    background: -moz-linear-gradient(top,  rgba(0,0,0,0.83) 0%, rgba(0,0,0,0.83) 60%, rgba(0,0,0,0.53) 84%, rgba(0,0,0,0) 100%);
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(0,0,0,0.83)), color-stop(60%,rgba(0,0,0,0.83)), color-stop(84%,rgba(0,0,0,0.53)), color-stop(100%,rgba(0,0,0,0)));
    background: -webkit-linear-gradient(top,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    background: -o-linear-gradient(top,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    background: -ms-linear-gradient(top,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    background: linear-gradient(to bottom,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#d4000000', endColorstr='#00000000',GradientType=0 );
  }
  // TV color 1
  @bgcolor:#373735;
  @bgimage: url(/images/shop/tv/tvbg-2.jpg);
  @bgimage2:url(/images/shop/tv/tvwavebg.png);
  @headerbg:url(/images/shop/tv/tv2headerbg.jpg);
  @shoptitlecolor: #fff;
  @shopnameshadow:.4rem .4rem 0rem #820000;
  @contentbgimage:url(/images/shop/utility/pipebg.png);
  @shopdesccolor:#fff;
  @shopdesbgcolor:#2a5d8c;
  @navbg:linear-gradient(to top, rgba(0,32,61,.35) 0%,rgba(255,255,255,.35) 100%);
  @activemenutabcolor: linear-gradient(to bottom, #1c3144 0%, #305678 50%);
  @homemsgcolor:#144a68;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @tabfontcolor: #820000;
  @kioskbg:#002140;
  @maincontentp:#2a5d8c;
  @maincontenth1:#00203c;
  @h1shadow:none;
  @activetabcolor:#fff;
  @buttonbackground:#2a5d8c;
  @buttonborder:#236db2;
  @buttonhoverbg:#1a4872;
  @buttonborderhover:#236db2;
  @tvh3bg:#2a5d8c;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @tablebg:rgba(0,32,60,.4);

  @import './tvLayout2.less';

}

</style>

<style lang="less">
.tv.layout2.color2 {
  .clearfix:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }
  .clearfix { display: inline-block; }
  * .shop-html .clearfix { height: 1%; }
  .clearfix { display: block; }

  /* TV common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @logoborder: 0.5rem solid #820000;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @tabactivefontcolor: #fff;
  @font-face {
      font-family: 'fugaz_oneregular';
      src: url('/fonts/FugazOne/fugazone-regular.eot');
      src: url('/fonts/FugazOne/fugazone-regular.eot?#iefix') format('embedded-opentype'),
          url('/fonts/FugazOne/fugazone-regular.woff') format('woff'),
          url('/fonts/FugazOne/fugazone-regular.ttf') format('truetype'),
          url('/fonts/FugazOne/fugazone-regular.svg#fugaz_oneregular') format('svg');
      font-weight: normal;
      font-style: normal;

  }
  @maincontentcolor: #2e2e2e;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }

  .bggradient() {
    background: -moz-linear-gradient(top,  rgba(0,0,0,0.83) 0%, rgba(0,0,0,0.83) 60%, rgba(0,0,0,0.53) 84%, rgba(0,0,0,0) 100%);
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(0,0,0,0.83)), color-stop(60%,rgba(0,0,0,0.83)), color-stop(84%,rgba(0,0,0,0.53)), color-stop(100%,rgba(0,0,0,0)));
    background: -webkit-linear-gradient(top,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    background: -o-linear-gradient(top,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    background: -ms-linear-gradient(top,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    background: linear-gradient(to bottom,  rgba(0,0,0,0.83) 0%,rgba(0,0,0,0.83) 60%,rgba(0,0,0,0.53) 84%,rgba(0,0,0,0) 100%);
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#d4000000', endColorstr='#00000000',GradientType=0 );
  }
 // TV color 2
  @bgcolor:#a1a09b;
  @bgimage: url(/images/shop/tv/tvbg2-2.jpg);
  @bgimage2:url(/images/shop/tv/tvwavebg2.png);
  @headerbg:url(/images/shop/tv/tv2headerbg2.jpg);
  @shoptitlecolor: #fff;
  @shopnameshadow:.4rem .4rem 0rem #820000;
  @contentbgimage:url(/images/shop/utility/pipe2bg.png);
  @shopdesccolor:#fff;
  @shopdesbgcolor:#414141;
  @navbg:linear-gradient(to top, rgba(0,32,61,.35) 0%,rgba(255,255,255,.35) 100%);
  @activemenutabcolor: linear-gradient(to bottom, #570200 0%, #9c0000 50%);
  @homemsgcolor:#7f0000;
  @navbgcolor: #2e55b0;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @tabfontcolor: #820000;
  @kioskbg:#2A5D8C;
  @maincontentp:#820000;
  @maincontenth1:#820000;
  @h1shadow:none;
  @activetabcolor:#fff;
  @buttonbackground:#820000;
  @buttonborder:#b23030;
  @buttonhoverbg:#5a0101;
  @buttonborderhover:#6f0000;
  @tvh3bg:#cf5353;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @tablebg:rgba(0,32,60,.4);

  @import './tvLayout2.less';

}

</style>

